@@ -24,6 +24,10 @@ int asyncSoftTest(void);
 int simmTest(void);
 int mbbioDirectTest(void);
 int scanEventTest(void);
+int boTest(void);
+int biTest(void);
+int printfTest(void);
+int aiTest(void);
 
 void epicsRunRecordTests(void)
 {
@@ -51,5 +55,13 @@ void epicsRunRecordTests(void)
 
     runTest(scanEventTest);
 
+    runTest(boTest);
+
+    runTest(biTest);
+
+    runTest(printfTest);
+
+    runTest(aiTest);
+
     epicsExit(0);   /* Trigger test harness */
 }
