@@ -104,6 +104,7 @@ static const ELEMENT operands[] = {
 {"F",           0, 0,   1,      OPERAND,        FETCH_F},
 {"FINITE",      7, 8,   0,      VARARG_OPERATOR,FINITE},
 {"FLOOR",       7, 8,   0,      UNARY_OPERATOR, FLOOR},
+{"FMOD",        7, 8,   -1,     UNARY_OPERATOR, FMOD},
 {"G",           0, 0,   1,      OPERAND,        FETCH_G},
 {"H",           0, 0,   1,      OPERAND,        FETCH_H},
 {"I",           0, 0,   1,      OPERAND,        FETCH_I},
@@ -334,6 +335,10 @@ LIBCOM_API long
             break;
 
         case SEPERATOR:
+            if (pstacktop == stack) {
+                *perror = CALC_ERR_BAD_SEPERATOR;
+                goto bad;
+            }
             /* Move operators to the output until open paren */
             while (pstacktop->name[0] != '(') {
                 if (pstacktop <= stack+1) {
@@ -352,6 +357,10 @@ LIBCOM_API long
             break;
 
         case CLOSE_PAREN:
+            if (pstacktop == stack) {
+                *perror = CALC_ERR_PAREN_NOT_OPEN;
+                goto bad;
+            }
             /* Move operators to the output until matching paren */
             while (pstacktop->name[0] != '(') {
                 if (pstacktop <= stack+1) {
