@@ -63,7 +63,7 @@ GPHENTRY * epicsStdCall gphFindParse(gphPvt *pgphPvt, const char *name, size_t l
     ELLLIST **paplist;
     ELLLIST *gphlist;
     GPHENTRY *pgphNode;
-    int hash;
+    unsigned hash;
 
     if (pgphPvt == NULL) return NULL;
     paplist = pgphPvt->paplist;
@@ -99,7 +99,7 @@ GPHENTRY * epicsStdCall gphAdd(gphPvt *pgphPvt, const char *name, void *pvtid)
     ELLLIST **paplist;
     ELLLIST *plist;
     GPHENTRY *pgphNode;
-    int hash;
+    unsigned hash;
 
     if (pgphPvt == NULL) return NULL;
     paplist = pgphPvt->paplist;
@@ -144,7 +144,7 @@ void epicsStdCall gphDelete(gphPvt *pgphPvt, const char *name, void *pvtid)
     ELLLIST **paplist;
     ELLLIST *plist = NULL;
     GPHENTRY *pgphNode;
-    int hash;
+    unsigned hash;
 
     if (pgphPvt == NULL) return;
     paplist = pgphPvt->paplist;
