@@ -239,7 +239,7 @@ struct PDBProcessor
 
 #ifdef USE_MULTILOCK
             try {
-                GroupConfig::parse(json, "", conf);
+                GroupConfig::parse(json, NULL, conf);
                 if(!conf.warning.empty())
                     fprintf(stderr, "warning(s) from dbGroup file \"%s\"\n%s", it->c_str(), conf.warning.c_str());
             }catch(std::exception& e){
@@ -438,6 +438,9 @@ PDBProvider::PDBProvider(const epics::pvAccess::Configuration::const_shared_poin
                         else
                             builder = builder->addNestedStructure(parts[j].name);
                     }
+                    if(parts.back().isArray()) {
+                        builder = builder->addNestedStructureArray(parts.back().name);
+                    }
                 }
 
                 if(!mem.structID.empty())
@@ -457,7 +460,7 @@ PDBProvider::PDBProvider(const epics::pvAccess::Configuration::const_shared_poin
 
                 std::tr1::shared_ptr<PVIFBuilder> pvifbuilder(PVIFBuilder::create(mem.type, chan.chan));
 
-                if(!parts.empty())
+                if(!parts.empty() && !parts.back().isArray())
                     builder = pvifbuilder->dtype(builder, parts.back().name);
                 else
                     builder = pvifbuilder->dtype(builder, "");
@@ -465,6 +468,8 @@ PDBProvider::PDBProvider(const epics::pvAccess::Configuration::const_shared_poin
                 if(!parts.empty()) {
                     for(size_t j=0; j<parts.size()-1; j++)
                         builder = builder->endNested();
+                    if(parts.back().isArray())
+                        builder = builder->endNested();
                 }
 
                 if(!mem.pvname.empty()) {
@@ -744,8 +749,6 @@ FieldName::FieldName(const std::string& pv)
     }
     if(parts.empty())
         throw std::runtime_error("Empty field name");
-    if(parts.back().isArray())
-        throw std::runtime_error("leaf field may not have sub-script : "+pv);
 }
 
 epics::pvData::PVFieldPtr
